<template>
  <div class="full-body">
    <div class="container" v-loading="loading" element-loading-text="拼命加载中"
         element-loading-spinner="el-icon-loading" element-loading-background="rgba(0, 0, 0, 0.1)">
      <template v-if="reportFormData.length !== 0">
        <div class="card-container">
          <div class="item-card" v-for="(item, index) in reportFormData" :key="index" :style="[{background:(item.failure>0?'linear-gradient(90deg, #FFEDED, #FFFFFF)':item.alarm>0?'linear-gradient(90deg, #FFF4F1, #FFFFFF)':'linear-gradient(90deg, #EFF4FF, #FFFFFF)')},{
							border:(item.failure>0?'1px solid #F29898':item.alarm>0?'1px solid #FFD8CC':'1px solid #C9D9FF')
						}]" >
            <div class="card-title">
              <div style="display: inline-block;border-radius: 50%;margin-right: 8px;"
                   :style="{background:(item.failure>0?' #F24B4B':item.alarm>0?' #FB9723':' #42C9FF'),padding: item.icon ? '5px 7px 6px' : '5px'}">
                <svgIcon icon-style="icon" :icon-class="item.icon" v-if="item.icon"
                         style="font-size: 16PX; vertical-align: middle;color: #fff !important;" />
              </div>

              {{ item.name }}
            </div>
            <div class="card-cont">
              <div class="cont-item">总数
                <div class="num">{{ item.allNum }}<span> 个</span></div>
              </div>
              <div class="cont-item">正常数
                <div class="normal">{{ item.normalNum }}<span> 个</span></div>
              </div>
              <div class="cont-item">故障数
                <div class="alarm">{{ item.failureNum }}<span> 个</span></div>
              </div>
              <div class="cont-item">报警数
                <div class="breakdown">{{ item.warnNum }}<span> 个</span></div>
              </div>
            </div>
          </div>
        </div>
      </template>
      <el-empty v-else description="暂无数据"></el-empty>
    </div>
  </div>
</template>

<script>
import utils from '@/utils.js'
import req from '@/request.js'

const portal = window.context.portal
import equipmentManage from '@/api/device/equipmentManage.js'
import resourceManage from '@/api/device/resourceManage.js'

export default {
  name: 'ReportManagement',
  components: {},
  data() {
    return {
      loading: false,
      reportFormData: [],
    }
  },
  created() {
    this.getReportForm(this.params) // 获取表报数据
  },
  methods: {

    // 获取报表数据
    getReportForm() {
      this.$http.post(window.context.portal + `/device/info/count/deviceParent`,{}).then(
        res => {
          if (res.data.state) {
            this.reportFormData = res.data.value
          }
        })
    },
  }
}
</script>

<style lang="scss" scoped>
.full-body {
  //   background: #fff;
}

.cqlt-icon {
  color: #fff;
  font-size: 48px;
}

.cqlt-icon-jidu {
  font-size: 38px;
}

::v-deep .el-pagination {
  margin-top: 10px;
  display: flex;
  justify-content: flex-end;
}

::v-deep .el-progress.is-success .el-progress-bar__inner {
  background: repeating-linear-gradient(120deg,
    #71b945,
    #71b945 0.26042vw,
    #8dc76a 0.26042vw,
    #8dc76a 0.625vw);
}

::v-deep .el-progress-bar__outer {
  height: 4px !important;
}

::v-deep .el-link {
  display: block;
}

::v-deep .el-tabs__nav-wrap::after {
  display: none;
}

::v-deep .el-tabs,
::v-deep .el-tabs__header,
::v-deep .el-tabs__nav-wrap,
::v-deep .el-tabs__nav-scroll,
::v-deep .el-tabs__nav {
  height: 100%;
}

::v-deep .el-tabs__nav {
  padding-top: 20px;
  box-sizing: border-box;
}

::v-deep .el-input__inner {
  // border: none;
}

.text-style {
  font-family: Microsoft YaHei;
  font-size: 16px;
  font-weight: normal;
  font-stretch: normal;
  line-height: 17px;
  letter-spacing: 0px;
  color: #0147eb;
}

// .icon {
// 	width: 40px;
// 	height: 40px;
// }

.flex {
  display: flex;
  align-items: center;
}

.mar-left-10 {
  margin-left: 10px;
}

.link-btn {
  display: flex;
  flex-direction: column;

  .item {
    display: flex;
    margin-top: 5px;
  }
}

.head-search {
  width: 100%;
  height: 78px;
  background-color: #fff;
  // box-shadow: 0px 12px 23px 0px rgba(0, 0, 0, 0.05);
  // border-radius: 20px;
  overflow: hidden;
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 0 25px;
  box-sizing: border-box;

  .el-tabs {
    width: inherit;
  }

  .left {
    height: 100%;
    display: flex;
    align-items: center;

    .icon-circle {
      display: inline-block;
      width: 14px;
      height: 14px;
      border-radius: 50%;
      overflow: hidden;
      margin-right: 10px;
    }

    .more-btn {
      margin-left: 32px;

      &:hover {
        cursor: pointer;

        i {
          color: #0147eb;
        }
      }

      span {
        font-family: Microsoft YaHei;
        font-size: 14px;
        font-weight: normal;
        font-stretch: normal;
        line-height: 19px;
        letter-spacing: 0px;
        color: #545454;
      }

      i {
        color: #545454;
      }
    }
  }

  .center {

    ::v-deep .el-form-item--small.el-form-item {
      margin-bottom: 0;
    }

    .addBtn {
      margin-left: 10px;
      //   height: 32PX;
    }
  }
}

.text-common-style {
  font-family: Microsoft YaHei;
  font-size: 12px;
  font-weight: normal;
  font-stretch: normal;
  line-height: 17px;
  letter-spacing: 0px;
  color: #ffffff;
}

.center {
  display: flex;
  justify-content: center;
  align-content: center;

  ::v-deep .el-form {
    height: 40px;
  }
}

.container {
  height: 100%;
  padding: 30px;
  overflow: auto;
  background-color: #fff;
  box-sizing: border-box;

  .item_title {
    height: 19px;
    font-size: 16px;
    font-weight: normal;
    font-stretch: normal;
    line-height: 19px;
    letter-spacing: 0px;
    color: #409eff;
    margin-top: 16px;
    margin-bottom: 10px;
    font-weight: 700;
    position: relative;

    &::before {
      content: '';
      position: absolute;
      top: 0;
      left: -10px;
      display: inline-block;
      width: 4px;
      height: 14px;
      line-height: 14px;
      background: #409eff;
    }
  }
}

::v-deep .el-loading-mask {
  border-radius: 20px;
}

::v-deep .el-empty {
  height: 100%;
  background: #fff;
  //   margin-top: 10px;
  border-radius: 20px;
}

.card-container {
  margin-top: 16px 0 8px 0;
  display: flex;
  flex-wrap: wrap;
  padding-right: 20px;

  .item-card {
    padding: 20px;
    box-sizing: border-box;
    background-color: #f5f6fa;
    border-radius: 20px;
    // box-shadow: 4px 4px 12px 0px rgba(0, 0, 0, 0.1);
    box-sizing: border-box;
    margin-right: 10px;
    margin-bottom: 10px;
    border: 1px solid #fff;

    &:hover {
      cursor: pointer;
      border: 1px dashed #409eff !important;
    }

    .card-title {
      font-size: 16PX;
      text-align: center;
      font-weight: 700;
      // color: #333333;
      margin-bottom: 10px;
    }

    .card-cont {
      padding: 10px 0;
      box-sizing: border-box;
      display: flex;
      justify-content: space-evenly;
      align-items: center;

      .cont-item {
        // width: 50%;
        // padding: 0 5%;
        // box-sizing: border-box;
        // display: flex;
        // justify-content: space-between;
        text-align: center;
        font-size: 14PX;
        color: #666666;

        div {
          font-size: 12PX;
          font-weight: 600;

          span {
            font-size: 12PX;
            color: #000 !important;
          }
        }

        .num {
          margin-top: 15px;
        }

        .normal {
          margin-top: 15px;
          color: #1890ff;
        }

        .breakdown {
          margin-top: 15px;
          color: #f9c700;
        }

        .alarm {
          margin-top: 15px;
          color: #ff8000;
        }
      }
    }
  }
}

.dialog-header {
  display: flex;
  height: 50px;
  align-items: center;
  margin-bottom: 10px;

  .line {
    margin: 0 30px;
  }

  .btn-plus {
    margin-right: 10px;
  }

  ::v-deep .el-form-item--small.el-form-item {
    margin-bottom: 0;
  }
}

@media screen and (max-width: 680px) {
  .item-card {
    width: 100%;
    margin-right: 0;
  }
}

@media screen and (min-width: 681px) {
  .item-card {
    width: calc(50% - 4px);
  }

  .item-card:nth-child(2n) {
    margin-right: 0px;
  }
}

@media screen and (min-width: 1040px) {
  .item-card {
    width: calc(33% - 4px);
  }

  .item-card:nth-child(2n) {
    margin-right: 10px;
  }

  .item-card:nth-child(2n + 1) {
    margin-right: 10px;
  }

  .item-card:nth-child(3n) {
    margin-right: 0;
  }

  .item-card:nth-child(3n + 1) {
    margin-right: 10px;
  }
}

@media screen and (min-width: 1350px) {
  .item-card {
    width: calc(25% - 8px);
  }

  .item-card:nth-child(2n) {
    margin-right: 10px;
  }

  .item-card:nth-child(2n + 1) {
    margin-right: 10px;
  }

  .item-card:nth-child(3n + 1) {
    margin-right: 10px;
  }

  .item-card:nth-child(3n) {
    margin-right: 10px;
  }

  .item-card:nth-child(4n + 1) {
    margin-right: 10px;
  }

  .item-card:nth-child(4n) {
    margin-right: 0px;
  }
}

@media screen and (min-width: 1710px) {
  .item-card {
    width: calc(20% - 8px);
  }

  .item-card:nth-child(2n) {
    margin-right: 10px;
  }

  .item-card:nth-child(3n) {
    margin-right: 10px;
  }

  .item-card:nth-child(4n) {
    margin-right: 10px;
  }

  .item-card:nth-child(5n) {
    margin-right: 0;
  }
}
</style>

<style lang="scss" scoped>
/* 弹层样式修改 */
.el-dialog__wrapper {
  ::v-deep .el-dialog {
    .el-dialog__body {
      padding: 10px;
    }
  }
}
</style>
